@@ -10,10 +10,6 @@ int main(int argc, char *argv[])
 #else
     w.show();
 #endif
-
-#ifdef Q_WS_MAEMO_5
-    w.setAttribute(Qt::WA_Maemo5AutoOrientation, true);
-#endif
-
+    w.enableAutoRotate();
     return a.exec();
 }
