@@ -4,64 +4,73 @@
 #include <QMessageBox>
 #include <QProcess>
 #include <QTimer>
+#include <QDebug>
 
 MainWindow::MainWindow(QWidget *parent) :
     QMainWindow(parent),
     ui(new Ui::MainWindow),
-    settings(new QSettings("tweakflashver", "main")),
     plugin(PLUGINPATH)
 {
+    qDebug() << "TweakFlashVer v0.2";
+
+    settings = new QSettings("tweakflashver", "main");
     ui->setupUi(this);
 
-    settings.beginGroup("global");
-    if (!QFile::exists(settings.value("pluginpath", PLUGINPATH).toString()))
+    qDebug() << "Loading... ";
+    loadFlashVers();
+    qDebug() << "Loaded";
+    if (ui->comboBox->count() == 0) // no version loaded from config
+    {
+        qDebug() << "Initializing settings";
+        settings->beginGroup("global");
+        settings->setValue("pluginpath", PLUGINPATH);
+        settings->setValue("pluginsize", PLUGINSIZE);
+        settings->endGroup();
+        settings->beginGroup("Android, 10.1.61 (FroYo)");
+        settings->setValue("part1","10.1 r61");
+        settings->setValue("part2","AND 10,1,61,0");
+        settings->setValue("index", 4);
+        settings->endGroup();
+        settings->beginGroup("Linux, 10.1.53 (Desktop)");
+        settings->setValue("part1","10.1 r53");
+        settings->setValue("part2","LNX 10,1,53,0");
+        settings->setValue("index", 3);
+        settings->endGroup();
+        settings->beginGroup("Linux, 10.0.45 (Desktop) - recommended");
+        settings->setValue("part1","10.0 r45");
+        settings->setValue("part2","LNX 10,0,45,0");
+        settings->setValue("index", 2);
+        settings->endGroup();
+        settings->beginGroup("Linux, 9.0.246 (PR1.1)");
+        settings->setValue("part1","9.0 r246");
+        settings->setValue("part2","LNX 9,0,246,0");
+        settings->setValue("index", 1);
+        settings->endGroup();
+        settings->beginGroup("Linux, 9.0.260 (PR1.2)");
+        settings->setValue("part1","9.0 r260");
+        settings->setValue("part2","LNX 9,0,260,0");
+        settings->setValue("index", 0);
+        settings->endGroup();
+        settings->sync();
+        qDebug() << "Default settings saved";
+        loadFlashVers();
+        qDebug() << "Settings re-loaded";
+    }
+
+    qDebug() << "Checking plugin file";
+    settings->beginGroup("global");
+    if (!QFile::exists(settings->value("pluginpath", PLUGINPATH).toString()))
     {
         QMessageBox::critical(this, tr("Error"), tr("Flash plugin file not found"));
         qApp->quit();
     }
-    else if (plugin.size() != settings.value("pluginsize", PLUGINSIZE).toUInt())
+    else if (plugin.size() != settings->value("pluginsize", PLUGINSIZE).toUInt())
     {
         QMessageBox::critical(this, tr("Error"), tr("Flash plugin file size mismatch"));
         qApp->quit();
     }
-    settings.endGroup();
-    settings.sync();
-
-    loadFlashVers();
-    if (ui->comboBox->count() == 0) // no version loaded from config
-    {
-        settings.beginGroup("global");
-        settings.setValue("pluginpath", PLUGINPATH);
-        settings.setValue("pluginsize", PLUGINSIZE);
-        settings.endGroup();
-        settings.beginGroup("Android, 10.1.61 (FroYo)");
-        settings.setValue("part1","10.1 r61");
-        settings.setValue("part2","AND 10,1,61,0");
-        settings.setValue("index", 4);
-        settings.endGroup();
-        settings.beginGroup("Linux, 10.1.53 (Desktop)");
-        settings.setValue("part1","10.1 r53");
-        settings.setValue("part2","LNX 10,1,53,0");
-        settings.setValue("index", 3);
-        settings.endGroup();
-        settings.beginGroup("Linux, 10.0.45 (Desktop) - recommended");
-        settings.setValue("part1","10.0 r45");
-        settings.setValue("part2","LNX 10,0,45,0");
-        settings.setValue("index", 2);
-        settings.endGroup();
-        settings.beginGroup("Linux, 9.0.246 (PR1.1)");
-        settings.setValue("part1","9.0 r246");
-        settings.setValue("part2","LNX 9,0,246,0");
-        settings.setValue("index", 1);
-        settings.endGroup();
-        settings.beginGroup("Linux, 9.0.260 (PR1.2)");
-        settings.setValue("part1","9.0 r260");
-        settings.setValue("part2","LNX 9,0,260,0");
-        settings.setValue("index", 0);
-        settings.endGroup();
-        settings.sync();
-        loadFlashVers();
-    }
+    settings->endGroup();
+    qDebug() << "Checks out OK";
 
     connect(ui->pushButton_2, SIGNAL(clicked()), this, SLOT(changeVer()));
     connect(ui->checkBox, SIGNAL(clicked(bool)), this, SLOT(setManualMode(bool)));
@@ -93,7 +102,10 @@ void MainWindow::setManualMode(bool b)
 
 void MainWindow::updateFields()
 {
-    QString str = settings.value(ui->comboBox->currentText()+"/part2").toString().right(9);
+    if (ui->comboBox->count() == 0)
+        return;
+
+    QString str = settings->value(ui->comboBox->currentText()+"/part2", "UNK   0,0,0,0").toString().right(9);
     QStringList fields = str.split(",");
     ui->lineEdit_2->setText(fields[0]);
     ui->lineEdit_3->setText(fields[1]);
@@ -108,8 +120,8 @@ void MainWindow::changeVer()
             QMessageBox::critical(this, tr("Error"), tr("Unable to create backup !"));
             return;
         }
-    QString part1 = settings.value(ui->comboBox->currentText()+"/part1").toString();
-    QString part2 = settings.value(ui->comboBox->currentText()+"/part2").toString();
+    QString part1 = settings->value(ui->comboBox->currentText()+"/part1").toString();
+    QString part2 = settings->value(ui->comboBox->currentText()+"/part2").toString();
 
     if (ui->checkBox->isChecked()) // manual
     {
@@ -151,7 +163,7 @@ void MainWindow::changeVer()
     plugin.close();
     readFlashVer();
 
-    QTimer::singleShot(1000, this, SLOT(enableAutoRotate()));
+//    QTimer::singleShot(1000, this, SLOT(enableAutoRotate()));
 }
 
 
@@ -165,15 +177,55 @@ void MainWindow::enableAutoRotate()
 
 void MainWindow::loadFlashVers()
 {
-    foreach (QString group, settings.childGroups())
-    {
-        if (group != "global")
-            ui->comboBox->addItem(group);
+    if (settings) {
+        foreach (QString group, settings->childGroups())
+        {
+            if (group != "global")
+                ui->comboBox->addItem(group);
+        }
+        updateFields();
     }
-    updateFields();
 }
 
 MainWindow::~MainWindow()
 {
     delete ui;
 }
+
+void MainWindow::on_actionAbout_Qt_triggered()
+{
+    qApp->aboutQt();
+}
+
+void MainWindow::on_actionAbout_triggered()
+{
+    QMessageBox::about(this, tr("Tweak Flash Plugin Version"), tr("This applications allows you to painlessly change the version of the Flash plugin reported to sites from a GUI. This will, however, NOT make Flash faster or sites genuinely requiring Flash 10 work. It is not a Flash 10.1 upgrade replacement. What it does is getting you around pesky Flash version checks. Enjoy. <BR><BR>Copyright (C) 2010 by Attila Csipa, licensed under the GNU GPL v2"));
+}
+
+void MainWindow::on_actionRestore_plugin_to_factory_state_triggered()
+{
+    QString ppath;
+    if (QFile::exists(PLUGINBACKPUPPATH))
+        ppath = PLUGINBACKPUPPATH;
+    else if (QFile::exists(PLUGINBACKPUPPATH_LEGACY))
+        ppath = PLUGINBACKPUPPATH_LEGACY;
+    else {
+            QMessageBox::critical(this, tr("Error"), tr("We're doomed ! Unable to find backup ! If you have removed it, please restore the file to %0").arg( PLUGINBACKPUPPATH));
+            return;
+    }
+
+    if (!QFile(ppath).exists() || QFile(ppath).size() != PLUGINSIZE)
+    {
+            QMessageBox::critical(this, tr("Error"), tr("We're doomed ! Unable to find backup ! If you have removed it, please restore the file to %0").arg( PLUGINBACKPUPPATH));
+            return;
+    }
+
+    if (!(QFile::remove(PLUGINPATH) && QFile::copy(ppath, PLUGINPATH)))
+    {
+        QMessageBox::critical(this, tr("Error"), tr("We're doomed ! Unable to restore backup !"));
+        return;
+    }
+    readFlashVer();
+    QMessageBox::information(this, tr("Success"), tr("Flash plugin restored to original state"));
+
+}
