@@ -6,7 +6,8 @@
 #include <QSettings>
 
 #define PLUGINPATH "/usr/lib/browser/plugins/libflashplayer.so"
-#define PLUGINBACKPUPPATH "/home/user/MyDocs/libflashplayer.so.pr1.2"
+#define PLUGINBACKPUPPATH_LEGACY "/home/user/MyDocs/libflashplayer.so.pr1.2"
+#define PLUGINBACKPUPPATH "/home/user/MyDocs/libflashplayer.so.pr12.tweakflashver"
 #define PLUGINSIZE 6723876
 #define OFFSET1 0x5B3D24
 #define OFFSET2 0x5CA71C
@@ -23,15 +24,20 @@ public:
     explicit MainWindow(QWidget *parent = 0);
     ~MainWindow();
 
+public slots:
+    void enableAutoRotate();    // cludge
+
 private slots:
+    void on_actionRestore_plugin_to_factory_state_triggered();
+    void on_actionAbout_triggered();
+    void on_actionAbout_Qt_triggered();
     void setManualMode(bool b); //! Use combobox or edit fields for version
     void updateFields();        //! change edit fields according to combo box content
     void changeVer();           //! Apply changes
-    void enableAutoRotate();    // cludge
 
 private:
     Ui::MainWindow *ui;
-    QSettings settings;   //! app cofnig
+    QSettings* settings;   //! app config
     QFile plugin;         //! the actual binary
     void loadFlashVers(); //! Load available premade versions from the config file
     void readFlashVer();  //! Load version from binary
